@@ -11,8 +11,9 @@ from typing import Any, Dict, List, Optional, Sequence, Union
 
 import httpcore
 import httpx
-import yaml
 from jinja2 import BaseLoader, ChoiceLoader, Environment, FileSystemLoader, PackageLoader
+from ruamel.yaml import YAML
+from ruamel.yaml.error import YAMLError
 
 from openapi_python_client import utils
 
@@ -350,8 +351,9 @@ def _load_yaml_or_json(data: bytes, content_type: Optional[str]) -> Union[Dict[s
             return GeneratorError(header=f"Invalid JSON from provided source: {err}")
     else:
         try:
-            return yaml.safe_load(data)
-        except yaml.YAMLError as err:
+            yaml = YAML(typ="safe")
+            return yaml.load(data)
+        except YAMLError as err:
             return GeneratorError(header=f"Invalid YAML from provided source: {err}")
 
 
